function eegplugin_mproject(fig, try_strings, catch_strings)


fullpath = which('eegplugin_mproject');
addpath(genpath(fullpath(1:end - length('eegplugin_mproject.m'))));

% ---------------------
studymenu = findobj(fig, 'tag', 'study');
submenu = uimenu(studymenu, 'label', 'Measure Projection Beta Demo');

erpmenu = uimenu( submenu, 'Label', 'ERP');
erspmenu = uimenu( submenu, 'Label', 'ERSP');



%-ERP menu---------
uimenu(erpmenu, 'Label', 'Project','Callback', @command_erp_project);
uimenu(erpmenu, 'Label', 'Create domains','Callback',@command_erp_create_domain);
erpdomains_menu = uimenu(erpmenu, 'Label', 'Domains','enable','off');
n_maxdomain = 5; %allowing max of 5 domains for demo
for i = 1:n_maxdomain
    erp_domain_menu = uimenu(erpdomains_menu, 'Label', ['Domain ' num2str(i)]);
    uimenu(erp_domain_menu,'Label', 'Show condition difference','Callback',@command_erp_show_domain_condition_difference, 'tag',['erpConditionDiffForDomain ' num2str(i)]);
    uimenu(erp_domain_menu,'Label', 'Show group difference','Callback',@command_erp_show_domain_group_difference, 'tag',['erpGroupDiffForDomain ' num2str(i)]);
    uimenu(erp_domain_menu,'Label', 'Show measure','Callback',@command_erp_show_domain_measure, 'tag',['erpMeasureForDomain ' num2str(i)]);
    uimenu(erp_domain_menu,'Label', 'Show volume','Callback',@command_erp_show_domain_volume,'tag',['erpVolumeForDomain ' num2str(i)],'separator','on');
    uimenu(erp_domain_menu,'Label', 'Show volume as MRI','Callback',@command_erp_show_domain_volume_as_mri,'tag',['erpVolumeMRIForDomain ' num2str(i)]);
    uimenu(erp_domain_menu,'Label', 'Show high contributing dipoles','Callback',@command_erp_show_domain_dipole,'tag',['erpDipoleForDomain ' num2str(i)]);
    uimenu(erp_domain_menu,'Label', 'Show high contributing scalp maps','Callback',@command_erp_show_domain_scalpmap,'tag',['erpScalpMapForDomain ' num2str(i)]);
    
end
uimenu(erpmenu, 'Label', 'Visualize','Callback',@command_erp_visualize,'separator','on');
uimenu(erpmenu, 'Label', 'Visualize as MRI','Callback',@command_erp_visualize_as_mri);



%---ERSP menu ------
uimenu(erspmenu, 'Label', 'Project','Callback',@command_ersp_project);
uimenu(erspmenu, 'Label', 'Create Domains','Callback',@command_ersp_create_domain);
erspdomains_menu = uimenu(erspmenu, 'Label', 'Domains','enable','off');
n_maxdomain = 5; %allowing max of 5 domains for demo
for i = 1:n_maxdomain
    ersp_domain_menu = uimenu(erspdomains_menu, 'Label', ['Domain ' num2str(i)]);
    uimenu(ersp_domain_menu,'Label', 'Show condition difference','Callback',@command_ersp_show_domain_condition_difference, 'tag',['erspConditionDiffForDomain ' num2str(i)]);
    uimenu(ersp_domain_menu,'Label', 'Show group difference','Callback',@command_ersp_show_domain_group_difference, 'tag',['erspGroupDiffForDomain ' num2str(i)]);
    uimenu(ersp_domain_menu,'Label', 'Show measure','Callback',@command_ersp_show_domain_measure,'tag',['erspVolumeForDomain ' num2str(i)]);
    uimenu(ersp_domain_menu,'Label', 'Show volume','Callback',@command_ersp_show_domain_volume,'tag',['erspVolumeForDomain ' num2str(i)],'separator','on');
    uimenu(ersp_domain_menu,'Label', 'Show volume as MRI','Callback',@command_ersp_show_domain_volume_as_mri,'tag',['erspVolumeMRIForDomain ' num2str(i)]);
    uimenu(ersp_domain_menu,'Label', 'Show high contributing dipoles','Callback',@command_ersp_show_domain_dipole,'tag',['erspDipoleForDomain ' num2str(i)]);
    uimenu(ersp_domain_menu,'Label', 'Show high contributing scalp maps','Callback',@command_ersp_show_domain_scalpmap,'tag',['erspScalpMapForDomain ' num2str(i)]);
    
end
uimenu(erspmenu, 'Label', 'Visualize','Callback',@command_ersp_visualize,'separator','on');
uimenu(erspmenu, 'Label', 'Visualize as MRI','Callback',@command_ersp_visualize_as_mri);



update_measure_projection_menu;
end


function command_measure_project(measureName)

% get the STUDY and ALLEEG variables from workspace
STUDY = evalin('base', 'STUDY;');
ALLEEG = evalin('base', 'ALLEEG;');

switch measureName
    case 'erp'
        STUDY.measureProjection.(measureName).object = pr.dipoleAndMeasureOfStudyErp(STUDY, ALLEEG);
    case 'ersp'
        STUDY.measureProjection.(measureName).object = pr.dipoleAndMeasureOfStudyErsp(STUDY, ALLEEG);
end;
STUDY.measureProjection.(measureName).headGrid = pr.headGrid(10);
STUDY.measureProjection.(measureName).projection = pr.meanProjection(STUDY.measureProjection.(measureName).object, STUDY.measureProjection.(measureName).object.getPairwiseMutualInformationSimilarity, STUDY.measureProjection.(measureName).headGrid);

STUDY = place_components_for_projection_of_measure(STUDY, measureName);

% put the STUDY variable back from workspace
assignin('base', 'STUDY', STUDY);
end

function command_measure_visualize(measureName)

% get the STUDY and ALLEEG variables from workspace
STUDY = evalin('base', 'STUDY;');

if ~are_the_same_components(STUDY, measureName)
    command_measure_project(measureName);
    STUDY = evalin('base', 'STUDY;');
end;

significanceLevel = 0.03;
STUDY.measureProjection.(measureName).projection.plotVolumeColoredByMeasure(STUDY.measureProjection.(measureName).object, significanceLevel)

% put the STUDY variable back from workspace
assignin('base', 'STUDY', STUDY);
end

function command_measure_visualize_as_mri(measureName)

% get the STUDY and ALLEEG variables from workspace
STUDY = evalin('base', 'STUDY;');

if ~are_the_same_components(STUDY, measureName)
    command_measure_project(measureName);
    STUDY = evalin('base', 'STUDY;');
end;

significanceLevel = 0.03;
STUDY.measureProjection.(measureName).projection.plotMri;

% put the STUDY variable back from workspace
assignin('base', 'STUDY', STUDY);
eeglab redraw;
end

function command_measure_create_domain(measureName)

% get the STUDY and ALLEEG variables from workspace
STUDY = evalin('base', 'STUDY;');

if ~are_the_same_components(STUDY, measureName)
    command_measure_project(measureName);
    STUDY = evalin('base', 'STUDY;');
end;

significanceLevel = 0.03;
maxDomainExemplarCorrelation = 0.8;
STUDY.measureProjection.(measureName).projection = STUDY.measureProjection.(measureName).projection.createDomain(STUDY.measureProjection.(measureName).object, maxDomainExemplarCorrelation, significanceLevel);

% put the STUDY variable back from workspace
assignin('base', 'STUDY', STUDY);
update_measure_projection_menu;
end

function command_measure_show_domain_volume(measureName)
    tagForHandle = get(gcbo, 'tag');
    if ischar(tagForHandle(end)) && ~isempty(tagForHandle(end))
        domainIndex = str2num(tagForHandle(end));
        STUDY = evalin('base', 'STUDY;');
        STUDY.measureProjection.(measureName).projection.domain(domainIndex).plotVolume;
    else
        return;
    end   
end

function command_measure_show_domain_measure(measureName)
    tagForHandle = get(gcbo, 'tag');
    if ischar(tagForHandle(end)) && ~isempty(tagForHandle(end))
        domainIndex = str2num(tagForHandle(end));
        STUDY = evalin('base', 'STUDY;');
        STUDY.measureProjection.(measureName).projection.domain(domainIndex).plotMeasure;
    else
        return;
    end   
end

function command_measure_show_domain_condition_difference(measureName)
    tagForHandle = get(gcbo, 'tag');
    if ischar(tagForHandle(end)) && ~isempty(tagForHandle(end))
        domainIndex = str2num(tagForHandle(end));
        STUDY = evalin('base', 'STUDY;');
        STUDY.measureProjection.(measureName).projection.domain(domainIndex).plotConditionDifference(STUDY.measureProjection.(measureName).object);
    else
        return;
    end   
end

function command_measure_show_domain_group_difference(measureName)
    tagForHandle = get(gcbo, 'tag');
    if ischar(tagForHandle(end)) && ~isempty(tagForHandle(end))
        domainIndex = str2num(tagForHandle(end));
        STUDY = evalin('base', 'STUDY;');
        STUDY.measureProjection.(measureName).projection.domain(domainIndex).plotGroupDifference(STUDY.measureProjection.(measureName).object);
    else
        return;
    end   
end

function command_measure_show_domain_volume_as_mri(measureName)
    tagForHandle = get(gcbo, 'tag');
    if ischar(tagForHandle(end)) && ~isempty(tagForHandle(end))
        domainIndex = str2num(tagForHandle(end));
        STUDY = evalin('base', 'STUDY;');
        STUDY.measureProjection.(measureName).projection.domain(domainIndex).plotMri;
        eeglab redraw;
    else
        return;
    end   
end

function command_measure_show_domain_dipole(measureName)
    tagForHandle = get(gcbo, 'tag');
    if ischar(tagForHandle(end)) && ~isempty(tagForHandle(end))
        domainIndex = str2num(tagForHandle(end));
        STUDY = evalin('base', 'STUDY;');
        STUDY.measureProjection.(measureName).projection.domain(domainIndex).plotDipole;
    else
        return;
    end   
end

function command_measure_show_domain_scalpmap(measureName)
    tagForHandle = get(gcbo, 'tag');
    if ischar(tagForHandle(end)) && ~isempty(tagForHandle(end))
        domainIndex = str2num(tagForHandle(end));
        STUDY = evalin('base', 'STUDY;');
        STUDY.measureProjection.(measureName).projection.domain(domainIndex).plotScalpMap;
    else
        return;
    end   
end



%--------------------ERP-------------------------
function command_erp_project(callerHandle, tmp)

command_measure_project('erp');
% % get the STUDY and ALLEEG variables from workspace
% STUDY = evalin('base', 'STUDY;');
% ALLEEG = evalin('base', 'ALLEEG;');
% 
% STUDY.measureProjection.erp.object = pr.dipoleAndMeasureOfStudyErp(STUDY, ALLEEG);
% STUDY.measureProjection.erp.headGrid = pr.headGrid(10);
% STUDY.measureProjection.erp.projection = pr.meanProjection(STUDY.measureProjection.erp.object, STUDY.measureProjection.erp.object.getPairwiseMutualInformationSimilarity, STUDY.measureProjection.erp.headGrid);
% 
% STUDY = place_components_for_projection_of_measure(STUDY, 'erp');
% 
% % put the STUDY variable back from workspace
% assignin('base', 'STUDY', STUDY);
end

function command_erp_visualize(callerHandle, tmp)

command_measure_visualize('erp');
% % get the STUDY and ALLEEG variables from workspace
% STUDY = evalin('base', 'STUDY;');
% 
% if ~are_the_same_components(STUDY, 'erp')
%     command_erp_project(0, 0);
% end;
% 
% significanceLevel = 0.03;
% STUDY.measureProjection.erp.projection.plotVolumeColoredByMeasure(STUDY.measureProjection.erp.object, significanceLevel)
% 
% % put the STUDY variable back from workspace
% assignin('base', 'STUDY', STUDY);
end

function command_erp_visualize_as_mri(callerHandle, tmp)
command_measure_visualize_as_mri('erp');
% % get the STUDY and ALLEEG variables from workspace
% STUDY = evalin('base', 'STUDY;');
% 
% if ~are_the_same_components(STUDY, 'erp')
%     command_erp_project(0, 0);
% end;
% 
% significanceLevel = 0.03;
% STUDY.measureProjection.erp.projection.plotMri;
% 
% % put the STUDY variable back from workspace
% assignin('base', 'STUDY', STUDY);
end

function command_erp_create_domain(callerHandle, tmp)
command_measure_create_domain('erp');
% % get the STUDY and ALLEEG variables from workspace
% STUDY = evalin('base', 'STUDY;');
% 
% if ~are_the_same_components(STUDY, 'erp')
%     command_erp_project(0, 0);
% end;
% 
% significanceLevel = 0.03;
% maxDomainExemplarCorrelation = 0.8;
% STUDY.measureProjection.erp.projection = STUDY.measureProjection.erp.projection.createDomain(STUDY.measureProjection.erp.object, maxDomainExemplarCorrelation, significanceLevel);
% 
% % put the STUDY variable back from workspace
% assignin('base', 'STUDY', STUDY);
% update_measure_projection_menu;
end

function command_erp_show_domain_volume(callerHandle, tmp)
    command_measure_show_domain_volume('erp');
%     tagForHandle = get(gcbo, 'tag');
%     if ischar(tagForHandle(end)) && ~isempty(tagForHandle(end))
%         domainIndex = str2num(tagForHandle(end));
%         STUDY = evalin('base', 'STUDY;');
%         STUDY.measureProjection.erp.projection.domain(domainIndex).plotVolume;
%     else
%         return;
%     end   
end

function command_erp_show_domain_measure(callerHandle, tmp)
command_measure_show_domain_measure('erp');
% tagForHandle = get(gcbo, 'tag');
% if ischar(tagForHandle(end)) && ~isempty(tagForHandle(end))
%     domainIndex = str2num(tagForHandle(end));
%     STUDY = evalin('base', 'STUDY;');
%     STUDY.measureProjection.erp.projection.domain(domainIndex).plotMeasure;
% else
%     return;
% end
end

function command_erp_show_domain_condition_difference(callerHandle, tmp)
command_measure_show_domain_condition_difference('erp');   
% tagForHandle = get(gcbo, 'tag');
%     if ischar(tagForHandle(end)) && ~isempty(tagForHandle(end))
%         domainIndex = str2num(tagForHandle(end));
%         STUDY = evalin('base', 'STUDY;');
%         STUDY.measureProjection.erp.projection.domain(domainIndex).plotConditionDifference(STUDY.measureProjection.erp.object);
%     else
%         return;
%     end   
end

function command_erp_show_domain_group_difference(callerHandle, tmp)
command_measure_show_domain_group_difference('erp');    
% tagForHandle = get(gcbo, 'tag');
%     if ischar(tagForHandle(end)) && ~isempty(tagForHandle(end))
%         domainIndex = str2num(tagForHandle(end));
%         STUDY = evalin('base', 'STUDY;');
%         STUDY.measureProjection.erp.projection.domain(domainIndex).plotGroupDifference(STUDY.measureProjection.erp.object);
%     else
%         return;
%     end   
end

function command_erp_show_domain_volume_as_mri(callerHandle, tmp)
command_measure_show_domain_volume_as_mri('erp');    
% tagForHandle = get(gcbo, 'tag');
%     if ischar(tagForHandle(end)) && ~isempty(tagForHandle(end))
%         domainIndex = str2num(tagForHandle(end));
%         STUDY = evalin('base', 'STUDY;');
%         STUDY.measureProjection.erp.projection.domain(domainIndex).plotMri;
%     else
%         return;
%     end   
end

function command_erp_show_domain_dipole(callerHandle, tmp)
command_measure_show_domain_dipole('erp');
% tagForHandle = get(gcbo, 'tag');
%     if ischar(tagForHandle(end)) && ~isempty(tagForHandle(end))
%         domainIndex = str2num(tagForHandle(end));
%         STUDY = evalin('base', 'STUDY;');
%         STUDY.measureProjection.erp.projection.domain(domainIndex).plotDipole;
%     else
%         return;
%     end   
end

function command_erp_show_domain_scalpmap(callerHandle, tmp)
command_measure_show_domain_scalpmap('erp');
%     tagForHandle = get(gcbo, 'tag');
%     if ischar(tagForHandle(end)) && ~isempty(tagForHandle(end))
%         domainIndex = str2num(tagForHandle(end));
%         STUDY = evalin('base', 'STUDY;');
%         STUDY.measureProjection.erp.projection.domain(domainIndex).plotScalpMap;
%     else
%         return;
%     end   
end



%--------------------ERSP------------------------
function command_ersp_project(callerHandle, tmp)
command_measure_project('ersp');
% % get the STUDY and ALLEEG variables from workspace
% STUDY = evalin('base', 'STUDY;');
% ALLEEG = evalin('base', 'ALLEEG;');
% 
% STUDY.measureProjection.ersp.object = pr.dipoleAndMeasureOfStudyErsp(STUDY, ALLEEG);
% STUDY.measureProjection.ersp.headGrid = pr.headGrid(10);
% STUDY.measureProjection.ersp.projection = pr.meanProjection(STUDY.measureProjection.ersp.object, STUDY.measureProjection.ersp.object.getPairwiseMutualInformationSimilarity, STUDY.measureProjection.ersp.headGrid);
% 
% STUDY = place_components_for_projection_of_measure(STUDY, 'ersp');
% 
% % put the STUDY variable back from workspace
% assignin('base', 'STUDY', STUDY);
end

function command_ersp_visualize(callerHandle, tmp)
command_measure_visualize('ersp');
% % get the STUDY and ALLEEG variables from workspace
% STUDY = evalin('base', 'STUDY;');
% 
% if ~are_the_same_components(STUDY, 'ersp')
%     command_ersp_project(0, 0);
% end;
% 
% significanceLevel = 0.03;
% STUDY.measureProjection.ersp.projection.plotVolumeColoredByMeasure(STUDY.measureProjection.ersp.object, significanceLevel)
% 
% % put the STUDY variable back from workspace
% assignin('base', 'STUDY', STUDY);
end

function command_ersp_visualize_as_mri(callerHandle, tmp)
command_measure_visualize_as_mri('ersp');
end

function command_ersp_create_domain(callerHandle, tmp)
command_measure_create_domain('ersp');
% % get the STUDY and ALLEEG variables from workspace
% STUDY = evalin('base', 'STUDY;');
% 
% if ~are_the_same_components(STUDY, 'ersp')
%     command_ersp_project(0, 0);
% end;
% 
% significanceLevel = 0.03;
% maxDomainExemplarCorrelation = 0.8;
% STUDY.measureProjection.ersp.projection = STUDY.measureProjection.ersp.projection.createDomain(STUDY.measureProjection.ersp.object, maxDomainExemplarCorrelation, significanceLevel);
% 
% % put the STUDY variable back from workspace
% assignin('base', 'STUDY', STUDY);
% update_measure_projection_menu;
end

function command_ersp_show_domain_volume(callerHandle, tmp)
command_measure_show_domain_volume('ersp');    
% tagForHandle = get(gcbo, 'tag');
%     if ischar(tagForHandle(end)) && ~isempty(tagForHandle(end))
%         domainIndex = str2num(tagForHandle(end));
%         STUDY = evalin('base', 'STUDY;');
%         STUDY.measureProjection.ersp.projection.domain(domainIndex).plotVolume;
%     else
%         return;
%     end   
end

function command_ersp_show_domain_measure(callerHandle, tmp)
command_measure_show_domain_measure('ersp');    
% tagForHandle = get(gcbo, 'tag');
%     if ischar(tagForHandle(end)) && ~isempty(tagForHandle(end))
%         domainIndex = str2num(tagForHandle(end));
%         STUDY = evalin('base', 'STUDY;');
%         STUDY.measureProjection.ersp.projection.domain(domainIndex).plotMeasure;
%     else
%         return;
%     end   
end

function command_ersp_show_domain_condition_difference(callerHandle, tmp)
command_measure_show_domain_condition_difference('ersp');   
% tagForHandle = get(gcbo, 'tag');
%     if ischar(tagForHandle(end)) && ~isempty(tagForHandle(end))
%         domainIndex = str2num(tagForHandle(end));
%         STUDY = evalin('base', 'STUDY;');
%         STUDY.measureProjection.erp.projection.domain(domainIndex).plotConditionDifference(STUDY.measureProjection.erp.object);
%     else
%         return;
%     end   
end

function command_ersp_show_domain_group_difference(callerHandle, tmp)
command_measure_show_domain_group_difference('ersp');    
% tagForHandle = get(gcbo, 'tag');
%     if ischar(tagForHandle(end)) && ~isempty(tagForHandle(end))
%         domainIndex = str2num(tagForHandle(end));
%         STUDY = evalin('base', 'STUDY;');
%         STUDY.measureProjection.erp.projection.domain(domainIndex).plotGroupDifference(STUDY.measureProjection.erp.object);
%     else
%         return;
%     end   
end

function command_ersp_show_domain_volume_as_mri(callerHandle, tmp)
command_measure_show_domain_volume_as_mri('ersp');    
% tagForHandle = get(gcbo, 'tag');
%     if ischar(tagForHandle(end)) && ~isempty(tagForHandle(end))
%         domainIndex = str2num(tagForHandle(end));
%         STUDY = evalin('base', 'STUDY;');
%         STUDY.measureProjection.erp.projection.domain(domainIndex).plotMri;
%     else
%         return;
%     end   
end

function command_ersp_show_domain_dipole(callerHandle, tmp)
command_measure_show_domain_dipole('ersp');
% tagForHandle = get(gcbo, 'tag');
%     if ischar(tagForHandle(end)) && ~isempty(tagForHandle(end))
%         domainIndex = str2num(tagForHandle(end));
%         STUDY = evalin('base', 'STUDY;');
%         STUDY.measureProjection.erp.projection.domain(domainIndex).plotDipole;
%     else
%         return;
%     end   
end

function command_ersp_show_domain_scalpmap(callerHandle, tmp)
command_measure_show_domain_scalpmap('ersp');
%     tagForHandle = get(gcbo, 'tag');
%     if ischar(tagForHandle(end)) && ~isempty(tagForHandle(end))
%         domainIndex = str2num(tagForHandle(end));
%         STUDY = evalin('base', 'STUDY;');
%         STUDY.measureProjection.erp.projection.domain(domainIndex).plotScalpMap;
%     else
%         return;
%     end   
end

%--------------------------------------------------------------------------




function res = are_the_same_components(STUDY, measureName)
res = false;
if isfield(STUDY,'cluster') && isfield(STUDY.cluster,'comps') && isfield(STUDY.cluster,'sets')
    if isfield(STUDY,'measureProjection') && isfield(STUDY.measureProjection, measureName) && isfield(STUDY.measureProjection.(measureName),'lastCalculation') && isfield(STUDY.measureProjection.(measureName).lastCalculation,'comps') && isfield(STUDY.measureProjection.(measureName).lastCalculation,'sets')
        if isequal(STUDY.measureProjection.(measureName).lastCalculation.sets,STUDY.cluster(1).sets) && isequal(STUDY.measureProjection.(measureName).lastCalculation.comps,STUDY.cluster(1).comps)
            res = true;
        else
            res = false;
        end
    end
end
end

function STUDY = place_components_for_projection_of_measure(STUDY, measureName)
    STUDY.measureProjection.(measureName).lastCalculation.sets = STUDY.cluster(1).sets;
    STUDY.measureProjection.(measureName).lastCalculation.comps = STUDY.cluster(1).comps;    
end

