function plot_dipplot_with_cortex(location, plotCortex, varargin)
%   plot_dipplot_with_cortex(location, varargin)

if nargin < 2
    plotCortex = true;
end;


if nargin < 1 || isempty(location)
    % dummy dipole
    sources(1).posxyz = [-95 -48 -28];
    sources(1).momxyz = [  0 58 -69];
    sources(1).rv     = 0.036;
    varargin = {'coordformat', 'MNI','spheres', 'on', 'dipolesize', 0, 'gui','off'};
else
    % create dummy source sturcture for dipplot
    sources = [];
    for i=1:size(location, 1)
        sources(i).posxyz = location(i,:);
        sources(i).momxyz = [0 0 0];
        sources(i).rv = 0.001;
    end;
end;


dipplot(sources,  varargin{:});

if plotCortex
    csf = load('standard_BEM_vol.mat'); % located in the measure projection toolbox folder
    csfVertices = csf.vol.bnd(3).pnt;
    
    hold on;    
    csfHandle = plotmesh(csf.vol.bnd(3).tri, csf.vol.bnd(3).pnt, [], false);
    set(csfHandle, 'facealpha',0.2);
    set(gcf,'Renderer' ,'opengl');
    reducepatch(csfHandle, 1/8); % 1/6 crashed the computer
    
    % each call to dipplot adds two new lights, so we need to remove them all,
    % then add two lights
    delete(findobj(gcf, 'type','light'));
    
    camlight left;
    camlight right;
    
    % since each dipplot has a camzoom, we have to zoom out
    %camzoom(1/(1.2^(2*(length(clusterNumbers)-1))));
    
    set(gca, 'CameraViewAngleMode', 'manual');
end;

view([40 34]);